tock: Theory of Computing toolKit — tock documentation

# tock: Theory of Computing toolKit

Tock stands for Theory Of Computing toolKit. It can simulate the automata taught in standard theory of computation courses (deterministic and nondeterministic finite automata, pushdown automata, and Turing machines). It can also simulate many extensions, like multiple stacks or tapes.

Contents:

- Tutorial
  - Deterministic finite automata
  - Nondeterministic finite automata
  - Regular expressions
  - Context-free grammars
  - Pushdown automata
  - Turing machines
  - More general machines
- Reference
  - Machines
  - Regular expressions and grammars
  - Reading and writing
  - Internal representation of machines

# Indexes

- Index

- Module Index

- Search Page